Modules
===========

Photometric Module
~~~~~~~~~~~~~~~~~~~
.. autoclass:: tshirt.pipeline.phot_pipeline.phot
   :members:

.. automodule:: tshirt.pipeline.phot_pipeline
   :members:

Spectroscopic Module
~~~~~~~~~~~~~~~~~~~~~
.. autoclass:: tshirt.pipeline.spec_pipeline.spec
   :members:

.. automodule:: tshirt.pipeline.spec_pipeline
   :members:

Instrument-Specific Modules
~~~~~~~~~~~~~~~~~~~~~~~~~~~~
.. automodule:: tshirt.pipeline.instrument_specific.hst_inst_funcs
   :members:

.. automodule:: tshirt.pipeline.instrument_specific.jwst_inst_funcs
   :members:


Image Preparation Module
~~~~~~~~~~~~~~~~~~~~~~~~~~~
.. automodule:: tshirt.pipeline.prep_images
   :members:

Pipeline Utilities
~~~~~~~~~~~~~~~~~~~~~~~~~~~
.. automodule:: tshirt.pipeline.utils
   :members:
   

Pipeline Analysis Module
~~~~~~~~~~~~~~~~~~~~~~~~~~~
.. automodule:: tshirt.pipeline.analysis
   :members:
   